Documentation
¶
Overview ¶
gomod.go contains the `gomod` subcommand logic, used to check the go version in go.mod files.
Package cmd contains the logic for the various sub-commands. root.go represents the main command and contains common flags and setup.
testfiles.go contains the logic for the test_files subcommand, used to check the test.files values in exercise .meta/config.json files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var EmptyJson = []string{
`"[^"]*":null,`,
`"[^"]*":\[\],`,
`"[^"]*":"",`,
`,"[^"]*":null`,
`,"[^"]*":\[\]`,
`,"[^"]*":""`,
}
Patterns to strip from JSON output.
Functions ¶
Types ¶
type ExerciseConfigFile ¶
type ExerciseConfigFile struct {
Authors []string `json:"authors"`
Contributors []string `json:"contributors"`
Files struct {
Solution []string `json:"solution"`
Test []string `json:"test"`
Example []string `json:"example"`
Editor []string `json:"editor"`
Invalidator []string `json:"invalidator"`
} `json:"files"`
Blurb string `json:"blurb"`
Source string `json:"source"`
Source_url string `json:"source_url"`
}
type ExerciseData ¶
func (ExerciseData) Check ¶
func (e ExerciseData) Check() error
Click to show internal directories.
Click to hide internal directories.